@@ -1,34 +1,23 @@
 /*
-    Copyright (C) 2013  David Edmundson (davidedmundson@kde.org)
+    SPDX-FileCopyrightText: 2013 David Edmundson (davidedmundson@kde.org)
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "persondata.h"
 
+#include "backends/abstractcontact.h"
+#include "backends/abstracteditablecontact.h"
+#include "backends/basepersonsdatasource.h"
+#include "backends/contactmonitor.h"
 #include "metacontact_p.h"
 #include "personmanager_p.h"
 #include "personpluginmanager.h"
-#include "backends/basepersonsdatasource.h"
-#include "backends/contactmonitor.h"
-#include "backends/abstractcontact.h"
-#include "backends/abstracteditablecontact.h"
 
-#include <QUrl>
 #include "kpeople_debug.h"
+
 #include <QStandardPaths>
+#include <QUrl>
 
 namespace KPeople
 {
@@ -43,9 +32,9 @@ public:
 
 using namespace KPeople;
 
-KPeople::PersonData::PersonData(const QString &id, QObject *parent):
-    QObject(parent),
-    d_ptr(new PersonDataPrivate)
+KPeople::PersonData::PersonData(const QString &id, QObject *parent)
+    : QObject(parent)
+    , d_ptr(new PersonDataPrivate)
 {
     Q_D(PersonData);
 
@@ -54,7 +43,7 @@ KPeople::PersonData::PersonData(const QString &id, QObject *parent):
     }
 
     QString personUri;
-    //query DB
+    // query DB
     if (id.startsWith(QLatin1String("kpeople://"))) {
         personUri = id;
     } else {
@@ -69,7 +58,7 @@ KPeople::PersonData::PersonData(const QString &id, QObject *parent):
 
     QMap<QString, AbstractContact::Ptr> contacts;
     for (const QString &contactUri : qAsConst(d->contactUris)) {
-        //load the correct data source for this contact ID
+        // load the correct data source for this contact ID
         const QString sourceId = contactUri.left(contactUri.indexOf(QStringLiteral("://")));
         Q_ASSERT(!sourceId.isEmpty());
         BasePersonsDataSource *dataSource = PersonPluginManager::dataSource(sourceId);
@@ -77,8 +66,8 @@ KPeople::PersonData::PersonData(const QString &id, QObject *parent):
             ContactMonitorPtr cw = dataSource->contactMonitor(contactUri);
             d->watchers << cw;
 
-            //if the data source already has the contact set it already
-            //if not it will be loaded when the contactChanged signal is emitted
+            // if the data source already has the contact set it already
+            // if not it will be loaded when the contactChanged signal is emitted
             if (cw->contact()) {
                 contacts[contactUri] = cw->contact();
             }
@@ -158,10 +147,10 @@ QVariant PersonData::contactCustomProperty(const QString &key) const
     return d->metaContact.personAddressee()->customProperty(key);
 }
 
-bool KPeople::PersonData::setContactCustomProperty(const QString& key, const QVariant& value)
+bool KPeople::PersonData::setContactCustomProperty(const QString &key, const QVariant &value)
 {
     Q_D(PersonData);
-    auto contact = dynamic_cast<AbstractEditableContact*>(d->metaContact.personAddressee().data());
+    auto contact = dynamic_cast<AbstractEditableContact *>(d->metaContact.personAddressee().data());
 
     return contact && contact->setCustomProperty(key, value);
 }
@@ -194,7 +183,7 @@ QString PersonData::email() const
 
 QStringList PersonData::groups() const
 {
-//     We might want to cache it eventually?
+    //     We might want to cache it eventually?
 
     const QVariantList groups = contactCustomProperty(AbstractContact::GroupsProperty).toList();
     QStringList ret;
@@ -221,5 +210,5 @@ QStringList PersonData::allEmails() const
 bool KPeople::PersonData::isEditable() const
 {
     Q_D(const PersonData);
-    return dynamic_cast<const AbstractEditableContact*>(d->metaContact.personAddressee().constData());
+    return dynamic_cast<const AbstractEditableContact *>(d->metaContact.personAddressee().constData());
 }
